import os
from cryptography.fernet import Fernet

class LJcrypt:
	
	def encrypt(self, fileName, keyName):
		key = Fernet.generate_key()
		
		with open(keyName + '.key', 'wb') as k:
			k.write(key)
		
		with open(fileName, 'rb') as f:
			data = f.read()
		encrypted = Fernet(key).encrypt(data)
		
		with open(fileName, 'wb') as f:
			f.write(encrypted)
	
	def decrypt(self, fileName, keyName):
		with open(keyName + '.key', 'rb') as k:
			key = k.read()
		
		with open(fileName, 'rb') as f:
			data = f.read()
		decrypted = Fernet(key).decrypt(data)
		
		with open(fileName, 'wb') as f:
			f.write(decrypted)
		
		os.remove(keyName + '.key')
	
	def author(self):
		print('Louiejay S. Boglosa')
		
crypt = LJcrypt() 


from setuptools import setup, find_packages
import codecs
import os

here = os.path.abspath(os.path.dirname(__file__))

VERSION = '0.0.6'
DESCRIPTION = 'Making Encrypting and Decrypting easy.'

# Setting up
setup(
    name="pyLJcrypt",
    version=VERSION,
    author="Louiejay S. Boglosa",
    author_email="boglosalouiejay@gmail.com",
    description=DESCRIPTION,
    packages=find_packages(),
    install_requires=['cryptography'],
    keywords=['python', 'cryptography', 'encrypting', 'decrypting'],
    classifiers=[
        "Programming Language :: Python :: 3",
        "Operating System :: Unix",
        "Operating System :: MacOS :: MacOS X",
        "Operating System :: Microsoft :: Windows",
        "Operating System :: POSIX :: Linux",
    ]
)